/***********************************************************

* Figures and graphs  *

* Fig. 1 - Google trends graph *
* Fig. 2 - Factiva data on newspaper articles graph *
* Fig. 3 - Evolution of revenues and expenditures by categories *
* Fig. 4 - Distribution of the election date *
* Fig. 8 - Graphs for preventivi and consuntivi *
* Fig. 9 - Coverage map

***********************************************************/



* Figure 1 - Google trends *

clear all

set scheme sol
insheet using ../../Data/Media_coverage/Google_Trends.csv

rename month dates

gen year = substr(dates,1,4)
destring year, replace
drop if year < 2006

gen month = substr(dates,6,2)
destring month, replace

gen date = mdy(month,1, year)
format date %td


gen dm = mofd(date)
format dm %tmMonYY

drop year month dates

tsset  dm, monthly
twoway tsline  bilancioconsuntivo, tlabel(2008m6 2007m6 2009m4 2010m4 2011m4 2012m4 2013m4 2014m4, labsize(medium) tpos(in)) /*
*/ ylabel(0 (50) 120, angle(vertical) nogrid val labsize(medium)) lwidth(thick) lcolor(navy) /*
*/ xlabel(#12, labsize(small) angle(horizontal)) graphregion(color(white)) /*
*/ tline(2009m4 2010m4 2011m4 2012m4 2013m4 2014m4 , lcolor(midblue) lpattern(dash) )  /*
*/ tline(2008m6 2007m6 , lcolor(midblue) lpattern(dash) )  /*
*/ xtitle("") ytitle(Google Trends Index) legend(off) graphr(fc(white)) 

graph export   ../../Results/Figures/Figure_1.eps, replace
graph export   ../../Results/Figures/Figure_1.png, replace



* Figure 2 -  Factiva data on newspaper articles *

set scheme sol 
use  ../../Data/Media_coverage/Data_factiva.dta, replace
keep if year <=2014 & year >=2006


gen articles = 1
collapse (first) article_date (sum) articles , by(month year)


gen dm = mofd(article_date)
format dm %tmMonYY
tsset  dm, monthly

twoway tsline articles, tlabel(2008m6 2007m6 2006m6 2009m4 2010m4 2011m4 2012m4 2013m4 2014m4, tpos(in) labsize(medium)) /*
*/ ylabel(0 (40) 120, angle(vertical) nogrid val labsize(medium)) lwidth(thick) lcolor(gs5) /*
*/ xlabel(#12, labsize(small) angle(horizontal)) graphregion(color(white)) /*
*/ tline(2009m4 2010m4 2011m4 2012m4 2013m4 2014m4 , lcolor(midblue) lpattern(dash) )  /*
*/ tline(2008m6 2007m6  2006m6 , lcolor(midblue) lpattern(dash) )  /*
*/ xtitle("") ytitle(N. of local newspaper articles) legend(off) graphr(fc(white)) 

graph export  ../../Results/Figures/Figure_2.eps, replace
graph export  ../../Results/Figures/Figure_2.png, replace



* Fig. 3 - Evolution of revenues and expenditures by categories *

clear
use  ../../Data/Final/Data_final.dta, replace

preserve

gen somma =  (Entr_alienaz + Entr_prestiti + Entr_extra + Entr_servizi +  Entr_trib + Entr_trasf)/1000000000 // In 1000 million euros
rename (Entr_alienaz - Entr_trasf  Totale_gen_entr) (v1 v2 v3 v4 v5 v6 v7)

keep id_towns year v1-v7 somma

forv i = 1(1)7 {
replace v`i' = v`i'/1000000000  // In 1000 million euros
}
*
gen cumulative = v1

replace v1 = cumulative

forv i = 2(1)6 { // Generate cumulative sums

replace cumulative = cumulative + v`i'
replace v`i' = cumulative

}
*

collapse  (sum)  v1-v6, by(year) // Getting cross-sectional means

twoway  (area v6 year, color(ebg*1.4)) (area v5 year , color(ltblue*1.1)) (area v4 year , color(ltblue*0.5))/*
*/      (area v3 year, color(erose*1.2)) (area v2 year, color(emidblue*0.8)) (area v1 year, color(emidblue*0.3)), /*
*/      xlabel(1998 (2) 2013, labsize(large)) ylabel(0 (15) 75, angle(horizontal) nogrid val labsize(large)) xtitle("") /*
*/      ytitle(Revenues (billion euros), size(large)) legend(off) graphr(fc(white)) /*
*/ 	    text(7 2003 "Disp.of public assets", size(large))   text(26.5 2003.8 "Loans", size(large)) text(34.9 2004.5 "Non-tax", size(large)) /*
*/ 	    text(44 2004.7 "Services", size(large))  text(52 2005.5 "Taxes", size(large))  text(62 2008 "Transfers", size(large)) 

graph export ../../Results/Figures/Figure_3A.eps, replace
graph export ../../Results/Figures/Figure_3A.png, replace

restore


preserve

gen somma =  (Spese_corr + Spese_cc + Spese_prestiti + Spese_servizi) /1000000000 // In 1000 million euros
rename (Spese_corr Spese_cc Spese_prestiti Spese_servizi Totale_gen_spese_pc) (v1 v2 v3 v4 v5)


keep id_towns year v1 v2 v3 v4 v5 somma
order id_towns year v1 v2 v3 v4 v5 somma


forv i = 1(1)5 {
replace v`i' = v`i'/1000000000  // In 1000 million euros
}
*
gen cumulative = v1

replace v1 = cumulative

forv i = 2(1)4 { // Generate cumulative sums

replace cumulative = cumulative + v`i'
replace v`i' = cumulative

}
*

collapse  (sum)  v1-v4, by(year) // Getting totals

* Slides *
twoway  (area v4 year, color(ebg*0.8)) (area v3 year , color(ltblue)) (area v2 year , color(emidblue*1.2))/*
*/ (area v1 year, color(erose*0.9)), xlabel(1998 (2) 2013, labsize(large))  ylabel(0 (15) 75, angle(horizontal) nogrid val labsize(large)) /*
*/ xtitle("") ytitle(Expenditures (billion euros), size(large)) legend(off) graphr(fc(white)) /*
*/ text(15 2002.5 "Current", size(large))   text(50 2003.5 "Investment",size(large)) text(69.8 2004.4 "Loans",size(large)) /*
*/ text(75.5 2004.4 "Services",size(large)) 
graph export ../../Results/Figures/Figure_3B.eps, replace
graph export ../../Results/Figures/Figure_3B.png, replace


restore



* Figure 4 - Distribution of the election date *

use  ../../Data/Final/Data_final.dta, replace
set scheme sol


gen Elections = .
forv i = 1999(1)2012 {
replace Elections = year if years_election == 1 & year == `i' 
}
*
set scheme sol

hist Elections, freq addlabels discrete xlabels(1999(2)2011, labsize(huge))/*
*/ addlabopts(mlabsize(huge)) xtitle("") ytitle(" ") yscale(off) xsize(7) ysize(2)

graph export  ../../Results/Figures/Figure_4.eps, replace
graph export  ../../Results/Figures/Figure_4.png, replace



* Figure 8 - Graphs for preventivi and consuntivi *

clear
use ../../Data/Final/Data_final.dta, replace
set scheme sol

** Remove outlier from preventivi following procedure **
gen tag_special = 0
label var tag_special "Tag for outlier in revenues"

foreach i of varlist Spese_corr_pr_pc  Spese_cc_pr_pc  {

* 1) 100 times the median *
egen median = median(`i')
gen outlier_med = 1 if `i'> 100*median & `i' !=.
bys id_towns: egen outliers_med = max(outlier_med)
replace tag_special = 1 if outliers_med == 1 

****************** Replace outliers with missing *************************************
replace `i' = . if outliers_med == 1 & `i' !=.
**************************************************************************************


* 2) Of the remainders, replace with missing towns that have an observation 10 times the std. deviation *
egen std  = sd(`i')
replace std  = 10*std
gen outlier = 1 if `i'> std & `i' !=.
bys id_towns: egen outliers = max(outlier)
replace tag_special = 2 if outliers == 1 
count if id_towns != id_towns[_n-1] & outliers_med == 1 

****************** Replace outliers with missing *************************************
replace `i' = . if outliers == 1 & `i' !=.
**************************************************************************************

drop std outlier_med outliers_med  median outlier*

}


* Correlations *
corr Spese_corr_pr_pc Spese_corr_pc
local corr1 = r(rho)
corr Spese_cc_pr_pc Spese_cc_pc
local corr2 = r(rho)


* Plots *
twoway (scatter Spese_corr_pr_pc Spese_corr_pc if Spese_corr_pc<6000, graphregion(color(white)) mcolor(gs4)  name(Spese3, replace) nodraw /*
*/ ylabel(, angle(horizontal) nogrid val) xtitle(Current expenditures (balance sheet)) ytitle(Current exp. (budget))/* 
*/ text(1000 4500  `"corr. = `=string(`corr1',"%6.2f")'"') ) 

twoway (scatter Spese_cc_pr_pc Spese_cc_pc , graphregion(color(white)) mcolor(gs4)  name(Spese4, replace) nodraw /*
*/ xlabel(0 (5000) 11000) ylabel(, angle(horizontal) nogrid val) /*
*/ xtitle(Investment expenditures (balance sheet)) ytitle(Investment exp. (budget)) /*
*/ text(25000 9500  `"corr. = `=string(`corr2',"%6.2f")'"') )   

graph combine Spese3 Spese4, rows(2)     graphregion(color(white))

graph export ../../Results/Figures/Figure_8.eps, replace  
graph export ../../Results/Figures/Figure_8.png, replace  





* Figure 9 - newspaper coverage map ** 
set scheme sol

forv i = 2003(4)2011 {

clear
use ../../Data/Final/Data_final.dta, replace

keep if year == `i' 

merge 1:1 town using  ../../Data/Maps/Italy_map_2001.dta

spmap copies_local_p using ../../Data/Maps/Italy_coord_2001.dta, id(_ID) /*
*/  osize(none) ocolor(Blues)  ndsize(none) fcolor(Blues) ndocolor(white) /*
*/  clmethod(custom) clbreaks(0 2 4 6 12) name(g`i', replace) title(`i', size(huge)) legend(size(vlarge))

}

graph combine g2003 g2007 g2011 , rows(1)  graphregion(color(white)) ysize(3) xsize(7)
graph export ../../Results/Figures/Figure_9.png, replace
graph export ../../Results/Figures/Figure_9.eps, replace

