/****************************************************************************************
 
Table 21 - Term limits and fiscal rules *

****************************************************************************************/


clear all
clear matrix
use ../../Data/Final/Data_final.dta, replace
do ../Auxiliary/Estimation_globals.do // Define global variables 

xtset id_towns year
set more off
 

*  Table 21 - Term limits and fiscal rules * 
local pol_controls "non_ordinary vote_share1"   // remove TL from controls for the term-limit regressions


eststo clear

eststo A: quietly:  areg  Spese_cc_pc $x1 $controls `pol_controls'   		i.year##i.region_code if term_limited == 0, cluster(id_towns)  absorb(id_towns)
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

eststo B: quietly:  areg  Spese_cc_pc $x1 $controls_panel `pol_controls'  i.year##i.region_code if term_limited == 1, cluster(id_towns) absorb(id_towns) 
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

eststo C: quietly:  areg  Spese_cc_pc $x1 $controls $pol_controls  		i.year##i.region_code if stability_pact == 0 & year >=2001 /*
*/  & population<=10000,  cluster(id_towns) absorb(id_towns)  // Restrict to municipalities close to 5,000 inhabitants thresholds
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

eststo D: quietly:  areg  Spese_cc_pc $x1 $controls_panel $pol_controls  i.year##i.region_code if stability_pact == 1 & year >=2001 /*
*/  & population<=10000,  cluster(id_towns) absorb(id_towns)  // Restrict to municipalities close to 5,000 inhabitants thresholds
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)


esttab A B C D using ../../Results/Tables/Table_21.tex, replace  se(%3.2f) r2 keep($x1 ) /*
*/ label   star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes/*
*/ s(vmean r2 N, label("Mean of dep. var." "\emph{R}$^2$  " "Obs.")) alignment(c) sfmt(0) r2(0) b(a2) /*
*/ mtitles("\specialcell{Not term-limited}" "\specialcell{Term-limited}" "\specialcell{No stability pact}" "\specialcell{Stability pact}") /* 
*/  mgroups("Term-limits" "Stability Pact",pattern(1 0 1 0)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 



