/****************************************************************************************

* Estimation - basic specifications *

*  	Table 1, 13 - Baseline results *
* 	Table 14 - total expenditures *

****************************************************************************************/

clear
use ../../Data/Final/Data_final.dta, replace

do ../Auxiliary/Estimation_globals.do // Define global variables 

xtset id_towns year
set more off


**** Table 1 - Baseline results ****

eststo clear

eststo: quietly: reg  Spese_cc_pc $x1 $controls $pol_controls i.year##i.region_code, cluster(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "N" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

eststo: quietly: areg  Spese_cc_pc $x1 $controls_panel $pol_controls i.year##i.region_code, cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

* Test that beta(t-2) and beta(t-1) are not statistically distinguishable *
test years_f0 = years_f_minus1		  // p-value = 0.2817  
test years_f_minus1 = years_f_minus2  // p-value = 0.0455


* No controls *
eststo:quietly: areg  Spese_cc_pc $x1 i.year##i.region_code, cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "N" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

* No year effects *
eststo: quietly: reg  Spese_cc_pc  $x1 $controls $pol_controls, cluster(id_towns) 
estadd local year_d "N" , replace
estadd local year_r "N" , replace
estadd local fixed "N" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)


* Short version (paper's Table 1) *
esttab  using ../../Results/Tables/Table_1.tex , replace  se(%3.2f) r2 keep($x1 ) /*
*/ label booktabs  star(* 0.10 ** 0.05 *** 0.01)  f gaps  nonotes/*
*/ s(vmean controls year_d year_r fixed r2 N, label("Mean of dep. var." "Controls" "Year Effects"  /*
*/ "Year-Region Effects" "Municipality Effects" "\emph{R}$^2$  " "Obs.")) alignment(c) sfmt(0) r2(0) b(a2) /*
*/  mgroups("Baseline specification" "W/o controls"/*
*/ "W/o year effects",pattern(1 0 1 1)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 

* Full version (Appendix Table 13)*
esttab  using  ../../Results/Tables/Table_13.tex, replace  se(%3.2f) r2 keep($x1 $controls $pol_controls) /*
*/ label booktabs  star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes/*
*/ s(vmean controls year_d  fixed r2 N, label("Mean of dep. var." "Controls" "Year Effects"  /*
*/ "Year-Region Effects" "Municipality Effects" "\emph{R}$^2$  " "Obs.")) /*
*/ alignment(c) sfmt(0) r2(0) b(a2) mgroups("Baseline specification" "W/o controls" "W/o year effects",pattern(1 0 1 1)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 


*** Table 14 - total expenditures ***

label var Totale_gen_spese_pc "Total exp."
 
eststo clear

eststo: quietly: reg  Totale_gen_spese_pc  $x1 $controls $pol_controls i.year##i.region_code, cluster(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "N" , replace
estadd local controls "Y" , replace
summ Totale_gen_spese_pc if e(sample)
estadd scalar vmean = r(mean)

eststo: quietly: areg  Totale_gen_spese_pc $x1 $controls_panel $pol_controls i.year##i.region_code, cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
summ Totale_gen_spese_pc if e(sample)
estadd scalar vmean = r(mean)

* No controls *
eststo:quietly: areg  Totale_gen_spese_pc $x1 i.year##i.region_code, cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "N" , replace
summ Totale_gen_spese_pc if e(sample)
estadd scalar vmean = r(mean)

* No year effects *
eststo: quietly: reg  Totale_gen_spese_pc  $x1 $controls $pol_controls, cluster(id_towns) 
estadd local year_d "N" , replace
estadd local year_r "N" , replace
estadd local fixed "N" , replace
estadd local controls "Y" , replace
summ Totale_gen_spese_pc if e(sample)
estadd scalar vmean = r(mean)


* Table 14 *
esttab  using ../../Results/Tables/Table_14.tex , replace  se(%3.2f) r2 keep($x1 ) /*
*/ label booktabs  star(* 0.10 ** 0.05 *** 0.01)  f gaps  nonotes/*
*/ s(vmean controls year_d year_r fixed r2 N, label("Mean of dep. var." "Controls" "Year Effects"  /*
*/ "Year-Region Effects" "Municipality Effects" "\emph{R}$^2$  " "Obs.")) alignment(c) sfmt(0) r2(0) b(a2) /*
*/  mgroups("Baseline specification" "W/o controls"/*
*/ "W/o year effects",pattern(1 0 1 1)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 

