/****************************************************************************************
 
Table 20 - Additional checks *

****************************************************************************************/


clear all
use ../../Data/Final/Data_final.dta, replace

do ../Auxiliary/Estimation_globals.do // Define global variables 

xtset id_towns year
set more off
set matsize 1000

local robustness_controls  "Spese_prestiti_pc debt_initial"
replace debt_initial= debt_initial/population

label var Spese_prestiti_pc "Loans payments p.c."
label var debt_initial "Accumulated debt p.c."

eststo clear

* Column I - adding debt payments and total accumulated debt as controls *
eststo A:  areg  Spese_cc_pc $x1 $controls_panel $pol_controls `robustness_controls' i.year##i.region_code, cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean) 

* Column II - Stopping in 2009 *
eststo C:  areg  Spese_cc_pc $x1  $controls_panel $pol_controls i.year##i.region_code if year <= 2009, cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

* Column III - No municipalities subject to Stability pact (only after 2001, see text) *
eststo D:  areg  Spese_cc_pc $x1  $controls_panel $pol_controls i.year##i.region_code if stability_pact == 0 & year >=2001, cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

* Column IV  - adding a lag of Y *
eststo E: xi: qui:  xtabond  Spese_cc_pc $x1 $controls_panel $pol_controls i.year*i.region_code, vce(robust)
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)


* Robustness table III - Output *
esttab A C D E using ../../Results/Tables/Table_20.tex, replace compress se r2(2) keep($x1 `robustness_controls') /*
*/ label booktabs  star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes /*
*/ s(vmean controls year_d year_r fixed r2 N, fmt(1 0 0 0 0 2 0) label("Mean of dep. var." "Controls" "Year Effects" "Year-Region Effects" "Municipality Effects" "\emph{R}$^2$  " "Obs.")) /*
*/ alignment(c)  b(a2) /*
*/ rename(L.Spese_cc_pc Inv) varlabels(Inv "Investment exp. t-1") /*
*/ mtitles("Controls for debt" "Drop > 2009" "No Stability Pact" "Adding a lag")  






