/****************************************************************************************
 
Table 9 - Using the alternative definition of Post (2009 and onwards = 1) *

****************************************************************************************/

clear
use ../../Data/Final/Data_final.dta, replace

do ../Auxiliary/Estimation_globals.do // Define global variables 

xtset id_towns year
set more off

local x1 "years_minus2 years_minus1 years_0 years_2  years_f_minus2_alt years_f_minus1_alt years_f0_alt years_f2_alt "

label var years_f_minus2_alt "3 years before elect.*Post"
label var years_f_minus1_alt "2 years before elect.*Post"
label var years_f0_alt "1 year before elect.*Post"
label var years_f1_alt "Election year*Post"
label var years_f2_alt "1 year after elect.*Post"

****************************************************************************************

****  Table 9 - Baseline - Using Post = 1 for 2009 onwards ****

eststo clear

eststo: quietly: reg  Spese_cc_pc `x1' $controls $pol_controls i.year##i.region_code, cluster(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "N" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

eststo: quietly: areg  Spese_cc_pc `x1' $controls_panel $pol_controls i.year##i.region_code, cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

* No controls *
eststo:quietly: areg  Spese_cc_pc `x1' i.year##i.region_code, cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "N" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

* No year effects *
eststo: quietly: reg  Spese_cc_pc  `x1' $controls $pol_controls, cluster(id_towns) 
estadd local year_d "N" , replace
estadd local year_r "N" , replace
estadd local fixed "N" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)


* Table 9 *
esttab  using ../../Results/Tables/Table_9.tex , replace  se(%3.2f) r2 keep(`x1' ) /*
*/ label booktabs  star(* 0.10 ** 0.05 *** 0.01)  f gaps  nonotes/*
*/ s(vmean controls year_d year_r fixed r2 N, label("Mean of dep. var." "Controls" "Year Effects"  /*
*/ "Year-Region Effects" "Municipality Effects" "\emph{R}$^2$  " "Obs.")) alignment(c) sfmt(0) r2(0) b(a2) /*
*/  mgroups("Baseline specification" "W/o controls"/*
*/ "W/o year effects",pattern(1 0 1 1)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
